@@ -291,8 +291,13 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
                 UpdateAppointment(Data);
             },
             eventRender: function(CalEvent, $Element) {
+
                 var $IconContainer,
-                    $Icon;
+                    $Icon,
+                    pluginData,
+                    Filter = $('#FilterAppointments').val(),
+                    Title,
+                    Description;
 
                 if (CalEvent.allDay
                     || CalEvent.recurring
@@ -317,7 +322,7 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
                     }
                     if (CalEvent.parentId) {
                         $Icon.clone()
-                            .addClass('fa-link')
+                            .addClass('fa-child')
                             .appendTo($IconContainer);
                     }
                     if (CalEvent.notification) {
@@ -331,10 +336,43 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
                             .appendTo($IconContainer);
                     }
 
+                    if (CalEvent.pluginData) {
+                        pluginData = Object.keys(CalEvent.pluginData).sort();
+
+                        $.each(pluginData, function (Key,PluginKey) {
+                            if (CalEvent.pluginData[PluginKey] && CalEvent.pluginData[PluginKey]['Icon'] !== 'undefined'){
+                                $Icon.clone()
+                                    .addClass('fa-' + CalEvent.pluginData[PluginKey]['Icon'])
+                                    .appendTo($IconContainer);
+                            }
+                        })
+                    }
+
                     // Prepend container to the appointment
                     $Element.find('.fc-content')
                         .prepend($IconContainer);
                 }
+
+                // FilterAppointments
+                Filter ? Filter = Filter.toLowerCase() : '';
+                CalEvent.title ? Title = CalEvent.title.toLowerCase() : {};
+                CalEvent.description ? Description = CalEvent.description.toLowerCase() : {};
+
+                // If we have a description we can try to Filter
+                if (Description) {
+                    Description = Description.includes(Filter);
+                }
+
+                // If we have a title we can try to filter
+                if (Title) {
+                    Title = Title.includes(Filter);
+                }
+
+                if(Title || Description || Filter.length < 1) {
+                    return true;
+                }
+                return false;
+
             },
             eventResizeStart: function(CalEvent) {
                 CurrentAppointment.start = CalEvent.start;
@@ -350,6 +388,7 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
                     PosX = 0,
                     PosY = 0,
                     TooltipHTML = Core.Template.Render('Agent/AppointmentCalendar/AppointmentTooltip', {
+                        'PluginGroups': Core.Config.Get('PluginGroups'),
                         'PluginList': Core.Config.Get('PluginList'),
                         'CalEvent': CalEvent,
                         'TooltipTemplateResource': Core.Config.Get('TooltipTemplateResource') || 0,
@@ -426,6 +465,11 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
             resourceLabelText: Core.Language.Translate('Resources')
         });
 
+        // Activate FilterAppointments
+        $('#FilterAppointments').on('keyup',function(){
+            $CalendarObj.fullCalendar('rerenderEvents');
+        })
+
         // Initialize datepicker
         $DatepickerObj.datepicker({
             showOn: 'button',
@@ -551,6 +595,7 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
                         resourceIds: AppointmentData.ResourceID,
                         resourceNames: AppointmentData.ResourceNames,
                         pluginData: AppointmentData.PluginData,
+                        pluginDataGroup: AppointmentData.PluginDataGroup,
                         calendarName: Calendar.CalendarName,
                         calendarColor: Calendar.Color,
                         notification: AppointmentData.NotificationDate.length ? true : false,
@@ -844,7 +889,8 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
             Recurring: AppointmentData.CalEvent.recurring ? '1' : '0',
             TeamID: AppointmentData.CalEvent.teamIds ? AppointmentData.CalEvent.teamIds : undefined,
             ResourceID: AppointmentData.CalEvent.resourceIds ? AppointmentData.CalEvent.resourceIds :
-                AppointmentData.CalEvent.resourceId ? [ AppointmentData.CalEvent.resourceId ] : undefined
+                AppointmentData.CalEvent.resourceId ? [ AppointmentData.CalEvent.resourceId ] : undefined,
+            Plugin: AppointmentData.CalEvent.pluginData,
         };
 
         // Assigned resource didn't change
@@ -1745,15 +1791,20 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
             $('.RemoveButton').off('click.AppointmentCalendar').on('click.AppointmentCalendar', function () {
                 var $RemoveObj = $(this),
                     PluginKey = $RemoveObj.data('pluginKey'),
-                    $PluginDataObj = $('#Plugin_' + Core.App.EscapeSelector(PluginKey)),
+                    $PluginDataObj = $('#Plugin_' + Core.App.EscapeSelector(PluginKey) + '_LinkList'),
                     PluginData = JSON.parse($PluginDataObj.val()),
                     LinkID = $RemoveObj.data('linkId').toString(),
-                    $Parent = $RemoveObj.parent();
+                    $Parent = $RemoveObj.parent(),
+                    $PluginContainer = $Parent.parent();
 
                 PluginData.splice(PluginData.indexOf(LinkID), 1);
                 $PluginDataObj.val(JSON.stringify(PluginData));
 
                 $Parent.remove();
+                
+                if ( $PluginContainer.children().length == 0 ) {
+                    $PluginContainer.text('');
+                }
 
                 return false;
             });
@@ -1761,7 +1812,7 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
 
         function AddLink(PluginKey, PluginURL, LinkID, LinkName) {
             var $PluginContainerObj = $('#PluginContainer_' + Core.App.EscapeSelector(PluginKey)),
-                $PluginDataObj = $('#Plugin_' + Core.App.EscapeSelector(PluginKey)),
+                $PluginDataObj = $('#Plugin_' + Core.App.EscapeSelector(PluginKey) + '_LinkList'),
                 PluginData = JSON.parse($PluginDataObj.val()),
                 $ExistingLinks = $PluginContainerObj.find('.Link_' + Core.App.EscapeSelector(LinkID)),
                 $LinkContainerObj = $('<div />'),
@@ -2081,6 +2132,7 @@ Core.Agent.AppointmentCalendar = (function (TargetNS) {
                 });
             });
         }
+        Core.App.Publish('Core.Agent.AppointmentCalendar.AgentAppointmentEdit');
     }
 
     Core.Init.RegisterNamespace(TargetNS, 'APP_MODULE');
